@@ -8,6 +8,8 @@ class BalderQueryDefaultMeta:
     abstract = False
     list = None
     filter = None
+    paginate = False
+    personal = None
     operation = None
     queryset = None
 
